%--------------------------------------------------------------------------
%------- Main code Chapter one: Introduction ------
%--------------------------------------------------------------------------
%---- This code is meant to help the reader going through the graphs and --
%---- estimates reported in Chapter one of the book                      --
%--------------------------------------------------------------------------

%--------------------------------------------------------------------------
%------- Housekeeping -----------------------------------------------------
%--------------------------------------------------------------------------

close all; clear all; clc; pause(0.01), randn('seed',sum(clock)), rand('seed',sum(clock)), warning off

addpath([pwd '\Input\']);
addpath([pwd '\Utilities\']);
addpath([pwd '\Output\']);
[data,textdata,raw] = xlsread('ie_data.xls','Data');
%[filename,pathname]=uigetfile('*.xls');
%[data,textdata,raw] = xlsread(filename,'Data');

US.P   = data(:,2);
US.D = data(:,3)/12;
US.CPI      = data(:,5);
US.BondYTM  = data(:,7);
US.DPratio      = US.D./US.P;
US.LogDPratio   = log(US.DPratio);
US.LogP     = log(US.P);
US.LogD     = log(US.D);
US.DivGrowth    =NaN(size(US.P));
US.DivGrowth(2:end,:)    = diff(US.LogD);
US.LogCPI       = log(US.CPI);
US.Returns.Monthly    =NaN(size(US.P));
US.Infl    =NaN(size(US.P));
US.Returns.Monthly(2:end,:)  = log((US.P(2:end)+US.D(2:end))./US.P(1:end-1));
US.Infl(2:end,:)             = diff(US.LogCPI);


%--------------------------------------------------------------------------
%-------- Creates returns at different frequencies ------------------------
%--------------------------------------------------------------------------

t = [1:size((US.P))];
% Calculate returns yearly
US.Returns.Yearly    =NaN(size(US.P));
for i=12:size(t,2)
US.Returns.Yearly(i,:) = sum(US.Returns.Monthly(t(i)-11:t(i)));
end
% Calculate returns on 10 years
US.Returns.TenYears= NaN(size(US.P));
for i=121:size(t,2)
US.Returns.TenYears(i,:) = sum(US.Returns.Monthly(t(i)-120:t(i)));
end
% Defining Sample 
date=datenum(textdata(8:end,1),'dd/mm/yyyy');%Convert dates into a serial number
s_start1 = '15/01/1948';
s_end1   = '15/11/2013';
date_find1=datenum([s_start1; s_end1],'dd/mm/yyyy'); % Lookup row number
ss1=datefind(date_find1(1,1),date); % Sample Start (First Raw)
se1=datefind(date_find1(2,1),date); % Sample End (Last Raw)
ObsSample = se1-ss1+1; % Number of observations within Sample
%--------------------------------------------------------------------------
%--------  Summary stats of the US ----------------------------------------
%--------------------------------------------------------------------------

stats = [mean(US.Returns.Monthly(121:end-3))*12 std(US.Returns.Monthly(121:end-3))*sqrt(12) skewness(US.Returns.Monthly(121:end-3)) kurtosis(US.Returns.Monthly(121:end-3));
    mean(US.Returns.Yearly(121:end-3)) std(US.Returns.Yearly(121:end-3)) skewness(US.Returns.Yearly(121:end-3)) kurtosis(US.Returns.Yearly(121:end-3));
    mean(US.Returns.TenYears(121:end-3))/10 std(US.Returns.TenYears(121:end-3))/sqrt(10) skewness(US.Returns.TenYears(121:end-3)) kurtosis(US.Returns.TenYears(121:end-3));    
    mean(US.Infl(121:end-3)) std(US.Infl(121:end-3)) skewness(US.Infl(121:end-3)) kurtosis(US.Infl(121:end-3));
    mean(US.LogDPratio(121:end-3)) std(US.LogDPratio(121:end-3)) skewness(US.LogDPratio(121:end-3)) kurtosis(US.LogDPratio(121:end-3))];

xlswrite('Output/Tables.xlsx',stats,'Table1','C3:F7');

x=min(US.Returns.Monthly(121:end-3));
a=mean(US.Returns.Monthly(121:end-3));
b=std(US.Returns.Monthly(121:end-3));
cdf('norm',x,a,b)
x=min(US.Returns.TenYears(121:end-3));
a=mean(US.Returns.TenYears(121:end-3));
b=std(US.Returns.TenYears(121:end-3));
cdf('norm',x,a,b)


% Create figure (1) returns at different frequencies   
run Figure001   

% Create figure (2) returns and volatilities
run Figure002

% Create figure (3) returns and dividends

run Figure003




%--------------------------------------------------------------------------
% Regressions of the aggregate returns on the dividend-yield 
% over different horizons (precictive regression)
%--------------------------------------------------------------------------
s_start1 = '15/01/1948';
s_end1   = '15/10/2012';
date_find1=datenum([s_start1; s_end1],'dd/mm/yyyy'); % Lookup row number
ss1=datefind(date_find1(1,1),date); % Sample Start (First Raw)
se1=datefind(date_find1(2,1),date); % Sample End (Last Raw)
ObsSample = se1-ss1+1; % Number of observations within Sample

res = predregression(US.Returns.Monthly(ss1+1:se1+1,:)*100,US.LogDPratio(ss1:se1));


%% --------------------------------------------------------------------------
% Estimate the model of noise and fundamentals
%--------------------------------------------------------------------------

rho1 =  exp(mean(log(US.P)-log(US.D)));
rho1 = rho1/(1+rho1);

rho0 = -log(1-rho1)-rho1*log(1/(1-rho1)-1);

% Estimate the aggregate dividend growth dynamics

spec  = garchset('VarianceModel','constant');
[Coeff,Errors,LLF,Innovations,Sigmas,Summary] = garchfit(spec,US.DivGrowth(ss1+1:se1+1,:)*100);

% Estimate the dynamics of the price-dividend ratio

spec1 = garchset('P',1,'Q',1,'R',1);
[Coeff1,Errors1,LLF1,Innovations1,Sigmas1,Summary1] = garchfit(spec1,US.LogDPratio(ss1+1:se1+1,:));













